// auth.js

let auth0Client;

async function initializeAuth0Client() {
  auth0Client = await auth0.createAuth0Client({
    domain: "dev-g4e7bfpbacem6e8d.au.auth0.com",
    clientId: "PaFcTx3jOQffBEMJaD6d3xnmgSmzmTzq",
    redirect_uri: window.location.origin + "/callback",
  });
}

async function login() {
  if (!auth0Client) {
    await initializeAuth0Client();
  }
  await auth0Client.loginWithRedirect();
}

async function logout() {
  if (!auth0Client) {
    await initializeAuth0Client();
  }
  await auth0Client.logout();
}

async function handleAuthentication() {
  if (!auth0Client) {
    await initializeAuth0Client();
  }
  if (window.location.pathname === "/callback" && window.location.search.includes("code=")) {
    await auth0Client.handleRedirectCallback();
    window.history.replaceState({}, document.title, "/");

    const user = await getUser();
    if (user) {
        registerUserWithWorker(user.sub);  // User's Auth0 ID is stored in the 'sub' field
    }
  }
}

async function isAuthenticated() {
  if (!auth0Client) {
    await initializeAuth0Client();
  }
  return await auth0Client.isAuthenticated();
}

async function getUser() {
  if (!auth0Client) {
    await initializeAuth0Client();
  }
  return await auth0Client.getUser();
}

async function registerUserWithWorker(auth0Id) {
  const response = await fetch("/register", {
    method: "POST",
    headers: {
        "Content-Type": "application/json"
    },
    body: JSON.stringify({ auth0Id })
  });

  if (response.ok) {
    console.log("User registered successfully with worker");
  } else {
    console.error("Failed to register user with worker", response);
  }
}

initializeAuth0Client();  // Initialise the Auth0 client when the script loads
